# -*- coding: utf-8 -*-
from setuphelpers import *
import platform


if platform.system() == 'Windows':
    binary = 'upsync.exe'
    bin_folder = makepath(programfiles(),'upsync')
    full_bin_path = makepath(bin_folder,binary)
else:
    bin_folder = '/opt/upsync'
    full_bin_path = makepath(bin_folder,'upsync')

store_path = makepath(bin_folder,'store')


def install():

    if not isdir(makepath( WAPT.wapt_base_dir,'waptserver')):
        if not params.get("install_with_luti", False):
            error('please install this package on waptserver')

    if platform.system() == 'Windows':
        nginxconf = makepath(install_location('WAPT Server_is1'),"waptserver""nginx","conf","nginx.conf")

        waptserver_ini = makepath(install_location('WAPT Server_is1'),"conf","waptserver.ini")
        config_service =  { 'Name': 'upsync',
                            'Description': 'upsync',
                            'Level': 10,
                            'StartWorkDir': bin_folder,
                            'Start': ['start:"%s" --metadata-store-path "%s"  --endpoint 127.0.0.1 --port 40080' % (full_bin_path,store_path)],
                            'StopRunAbortTimeoutSec': 0,
                            'RetryStableSec': 60,
                            'WatchDelaySec': 60,
                            'RedirectLogRotateFiles': 2,
                            'RedirectLogRotateBytes': 104857600,
                            'ConfigFilename': "%agl.base%conf\\waptserver.ini"}

        conf_service = makepath(install_location('WAPT Server_is1'),"waptserver","services","upsync.service")
        with open(conf_service,'w') as f:
            f.write(json.dumps(config_service))


    else:
        nginxconf = "/etc/nginx/sites-enabled/wapt.conf"
        filecopyto('upsync.service','/usr/lib/systemd/system/upsync.service')
        waptserver_ini = '/opt/wapt/conf/waptserver.ini'
        run("systemctl daemon-reload")
        run("systemctl enable upsync")
        systemd_restart_service('upsync')


    inifile_writestring(waptserver_ini,"options","wuserver","http://127.0.0.1:40080")

    data_nginx_migration = """
    location /upsync/ClientWebService {
      proxy_pass http://127.0.0.1:40080/ClientWebService;
    }

    location ^~ /.well-known/acme-challenge/ {"""


    with open(nginxconf,'r') as f:
         data = f.read()

    if not "/upsync/ClientWebService" in data:
        newdata = data.replace("location ^~ /.well-known/acme-challenge/ {",data_nginx_migration)

        with open(nginxconf,'w') as f:
             f.write(newdata)

    if platform.system() == 'Windows':
        run('net stop waptserver')
        run('net start waptserver')
    else:
        run('systemctl reload nginx')

def audit():

    data = run('"%s" pre-fetch --store-path "%s"' % (full_bin_path,makepath(basedir,'store')),timeout=86400)

    list_cassification = {
        #"5c9376ab-8ce6-464a-b136-22113dd69801": "Application",
        #"434de588-ed14-48f5-8eed-a15e09a991f6": "Connectors",
        "e6cf1350-c01b-414d-a61f-263d14d133b4": "CriticalUpdates",
        #"e0789628-ce08-4437-be74-2495b842f43b": "DefinitionUpdates",
        #"e140075d-8433-45c3-ad87-e72345b36078": "DeveloperKits",
        "b54e7d24-7add-428f-8b75-90a396fa584f": "FeaturePacks",
        #"9511d615-35b2-47bb-927f-f73d8e9260bb": "Guidance",
        "0fa1201d-4330-4fa8-8ae9-b877473b6441": "SecurityUpdates",
        "68c5b0a3-d1a6-4553-ae49-01d3a7827828": "ServicePacks",
        "b4832bd8-e735-4761-8daf-37f882276dab": "Tools",
        "28bc880e-0592-4cbf-8f95-c79b17911d5f": "UpdateRollups",
        "cd5ffd1e-e932-4e3a-bf74-18bf0b1bbd83": "Updates"
    }

    for u in list_cassification:
        run('"%s" fetch --store-path "%s" --classification-filter %s' % (full_bin_path,makepath(basedir,'store'),u),timeout=86400)
    return "OK"

